@@ -4,19 +4,25 @@
 #' @param lat Input the latitude.
 #' @export
 #' @import sf
-#' @import sp
 #' @examples
 #' idfport(121.8006,25.14065)
 
+idfport <- function(lon, lat) {
 
-idfport <- function(lon,lat) {
+  ports <- get("port_sf")
+  port_sf <- st_as_sf(ports)
 
-  port <- get("port")
-  port_sf <- st_as_sf(port)
-  port_sf <- st_set_crs(port_sf,NA)
 
-  point <- data.frame(lon=lon, lat=lat)
-  point_sf <- st_as_sf(point, coords = c("lon", "lat"))
+  if (any(!st_is_valid(port_sf))) {
+    port_sf <- st_make_valid(port_sf)
+  }
+
+
+  point <- data.frame(lon = lon, lat = lat)
+  point_sf <- st_as_sf(point, coords = c("lon", "lat"), crs = 4326)
+
+
+  st_crs(port_sf) <- st_crs(point_sf)
 
 
   result <- suppressWarnings(st_intersection(port_sf, point_sf))
